%define oname Ardour
%define maj %{expand:%(echo "%{version}" | cut -d. -f1)}

Name:    ardour
Epoch:   1
Version: 8.6.0
Release: %mkrel 1
Summary: Professional multi-track audio recording application
Group:   Sound/Editors and Converters
License: GPLv2+
URL:     https://ardour.org/

Source0: https://community.ardour.org/download?architecture=x86_64&type=source#/%{oname}-%{version}.tar.bz2

BuildRequires: boost-devel
BuildRequires: dmalloc
BuildRequires: doxygen
BuildRequires: gettext
BuildRequires: graphviz
BuildRequires: gtk2-devel >= 2.12.1
BuildRequires: gtkmm2.4-devel >= 2.8
BuildRequires: pkgconfig(jack)
BuildRequires: readline-devel
BuildRequires: shared-mime-info
BuildRequires: xdg-utils
BuildRequires: pkgconfig(alsa)
BuildRequires: pkgconfig(aubio) >= 0.3.2
BuildRequires: pkgconfig(cairo)
BuildRequires: pkgconfig(cairomm-1.0)
BuildRequires: pkgconfig(cppunit) >= 1.12.0
BuildRequires: pkgconfig(dbus-1)
BuildRequires: pkgconfig(cwiid)
BuildRequires: pkgconfig(fftw3)
BuildRequires: pkgconfig(flac) >= 1.2.1
BuildRequires: pkgconfig(glib-2.0) >= 2.2
BuildRequires: pkgconfig(libarchive) >= 3.0.0
BuildRequires: pkgconfig(libart-2.0)
BuildRequires: pkgconfig(libcurl) >= 7.0.0
BuildRequires: pkgconfig(libgnomecanvas-2.0) >= 2.30
BuildRequires: pkgconfig(liblo) >= 0.24
BuildRequires: pkgconfig(libusb)
BuildRequires: pkgconfig(libusb-1.0)
BuildRequires: pkgconfig(libxslt)
BuildRequires: pkgconfig(lilv-0) >= 0.14
BuildRequires: pkgconfig(lrdf) >= 0.4.0
BuildRequires: pkgconfig(ltc) >= 1.1.0
BuildRequires: pkgconfig(lv2)
BuildRequires: pkgconfig(ogg) >= 1.1.2
BuildRequires: pkgconfig(python3)
BuildRequires: pkgconfig(raptor2)
BuildRequires: pkgconfig(redland)
BuildRequires: pkgconfig(rubberband)
BuildRequires: pkgconfig(samplerate)
BuildRequires: pkgconfig(serd-0) >= 0.14.0
BuildRequires: pkgconfig(sndfile) >= 1.0.18
BuildRequires: pkgconfig(sord-0) >= 0.8.0
BuildRequires: pkgconfig(sqlite3)
BuildRequires: pkgconfig(sratom-0) >= 0.4.0
BuildRequires: pkgconfig(suil-0) >= 0.6.0
BuildRequires: pkgconfig(taglib)
BuildRequires: pkgconfig(uuid)
BuildRequires: pkgconfig(vamp-sdk)
BuildRequires: desktop-file-utils

Requires: jackit
Requires: gtk2-clearlooks-engine

#to ensure that all LV2 plugins will work properly:
Requires: suil-x11-in-gtk2

Obsoletes: %{name}3 < 4.0
Conflicts: %{name}3 < 4.0
Provides:  %{name}3 = %{version}-%{release}

%description
Ardour is a digital audio workstation. You can use it to record, edit and mix
multi-track audio and MIDI. You can produce your own CDs, mix video sound
tracks, or just experiment with new ideas about music and sound.

Ardour capabilities include: multi channel recording, non-destructive editing
with unlimited undo/redo, full automation support, LV2 and Linux VST plugins 
support, a powerful mixer, unlimited tracks/buses/plugins, time-code
synchronization, and hardware control from surfaces like the
Mackie Control Universal.

%prep
%setup -q -n %{oname}-%{version}

%build
export CFLAGS="%optflags"

%{__python3} ./waf configure \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --configdir=%{_sysconfdir} \
    --program-name=Ardour \
    --docs \
    --cxx11 \
    --optimize \
    --with-backends="jack,alsa,dummy " \
    --no-phone-home

%{__python3} ./waf build \
    --docs

%{__python3} ./waf i18n_mo

%install
%{__python3} ./waf install --destdir=%{buildroot}

# Symlink icons and mimetypes into the right folders
install -d -m 0755 %{buildroot}%{_iconsdir}

for i in 16 22 32 48; do
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps
install -d -m 0755 %{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes
ln -s %{_datadir}/%{name}%{maj}/icons/application-x-%{name}_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/mimetypes/application-x-%{name}%{maj}.png
ln -s %{_datadir}/%{name}%{maj}/icons/application-x-%{name}_${i}px.png \
%{buildroot}%{_iconsdir}/hicolor/${i}x${i}/apps/%{name}%{maj}.png
done

cat>%{name}.desktop<<EOF
[Desktop Entry]
Comment=Digital Audio Workstation
Comment[en_GB]=Digital Audio Workstation
Comment[ru_RU]=Программа звукозаписи
Exec=ardour%{maj}
GenericName=%{oname}
GenericName[en_GB]=%{oname}
Icon=%{name}%{maj}
MimeType=application/x-%{name};
Name=%{oname}
Name[en_GB]=%{oname}
StartupNotify=true
Terminal=false
Type=Application
Categories=AudioVideo;Audio;X-Recorders;X-Multitrack;X-Jack;X-Mageia-CrossDesktop;

EOF

desktop-file-install \
--dir=%{buildroot}%{_datadir}/applications %{name}.desktop

cat > README.urpmi <<EOF
You will need to add yourself to the 'audio' and 'realtime' groups before using Ardour.
This may be done in a terminal by using the following commands:

su

gpasswd -a <yourusername> audio

gpasswd -a <yourusername> realtime

exit

You can alternatively do this by using the Mageia Control Center GUI:
System -> Manage Users on System -> Right click on your user, twice -> Edit -> Groups tab -> 
Check boxes for audio and realtime groups -> Click on OK

You will need to log out and log back in before using Ardour for the first time.

EOF

cp -a README.urpmi README.Mageia

%files
%doc README README.urpmi README.Mageia
%{_bindir}/%{name}%{maj}
%{_bindir}/%{name}%{maj}-lua
%{_bindir}/%{name}%{maj}-copy-mixer
%{_bindir}/%{name}%{maj}-export
%{_bindir}/%{name}%{maj}-new_empty_session
%{_bindir}/%{name}%{maj}-new_session
%{_libdir}/%{name}%{maj}
%{_datadir}/%{name}%{maj}
%{_datadir}/applications/%{name}.desktop
%dir %{_sysconfdir}/%{name}%{maj}
%{_iconsdir}/hicolor/*/*/*ardour8.png
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/%{name}.menus
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/clearlooks.ardoursans.rc
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/default_ui_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/system_config
%config(noreplace) %{_sysconfdir}/%{name}%{maj}/ardour.keys


%changelog
* Wed Jul 10 2024 papoteur <papoteur> 1:8.6.0-1.mga10
+ Revision: 2080500
- fix file list with new executables
- new version 8.6.0

* Wed Sep 27 2023 papoteur <papoteur> 1:7.5.0-1.mga10
+ Revision: 1991395
- new 7.5.0
+ kekepower <kekepower>
- Update to version 7.4.0

* Tue Feb 14 2023 kekepower <kekepower> 1:7.3.0-1.mga9
+ Revision: 1942388
- Update to version 7.3.0

* Sat Jan 28 2023 wally <wally> 1:7.2.0-2.mga9
+ Revision: 1936638
- don't own hicolor icon dirs

* Tue Dec 13 2022 kekepower <kekepower> 1:7.2.0-1.mga9
+ Revision: 1921490
- Update to version 7.2.0

* Sun Nov 20 2022 wally <wally> 1:7.1.0-2.mga9
+ Revision: 1909253
- rebuild for flac 1.4.2

* Thu Nov 03 2022 kekepower <kekepower> 1:7.1.0-1.mga9
+ Revision: 1902209
- Update to version 7.1.0

* Sun Oct 16 2022 kekepower <kekepower> 1:7.0-1.mga9
+ Revision: 1897101
- Update to version 7.0

* Sun Sep 25 2022 barjac <barjac> 1:6.9.0-4.mga9
+ Revision: 1892284
- revert change to clang and test build on all arches

* Sat Sep 24 2022 barjac <barjac> 1:6.9.0-3.mga9
+ Revision: 1892064
- restrict builds to 64bit arch

* Sat Sep 24 2022 barjac <barjac> 1:6.9.0-2.mga9
+ Revision: 1891984
- Exclude i586 from build
- fix build
+ kekepower <kekepower>
- Update to version 6.9.0
+ umeabot <umeabot>
- Mageia 9 Mass Rebuild

* Thu Jun 24 2021 kekepower <kekepower> 1:6.7.0-1.mga9
+ Revision: 1732164
- Update to version 6.7.0
+ daviddavid <daviddavid>
- remove suil-qt4 dependencies

* Sun Oct 18 2020 barjac <barjac> 1:6.3.0-1.mga8
+ Revision: 1636682
- new version 6.3.0
- update Source0
- build with python3
- fix over long description lines
- fix files list

* Thu Feb 20 2020 umeabot <umeabot> 1:5.12.0-8.mga8
+ Revision: 1546960
- Mageia 8 Mass Rebuild

* Thu Feb 06 2020 luigiwalser <luigiwalser> 1:5.12.0-7.mga8
+ Revision: 1487341
- rebuild for readline
+ tv <tv>
- rebuild for new readline

* Thu May 02 2019 wally <wally> 1:5.12.0-5.mga7
+ Revision: 1396197
- require clearlooks gtk2 engine

* Fri Sep 21 2018 umeabot <umeabot> 1:5.12.0-4.mga7
+ Revision: 1294536
- Mageia 7 Mass Rebuild

* Sun Feb 11 2018 semiletov <semiletov> 1:5.12.0-3.mga7
+ Revision: 1200446
- recuired-libs has been added to ensure proper LV2-plugins loading; description fixes

* Sat Feb 03 2018 zezinho <zezinho> 1:5.12.0-2.mga7
+ Revision: 1198709
- rebuild against new vamp-plugins-sdk-2.7.1

* Sun Oct 22 2017 zezinho <zezinho> 1:5.12.0-1.mga7
+ Revision: 1173109
- new version

* Tue Aug 08 2017 daviddavid <daviddavid> 1:5.9.0-2.mga7
+ Revision: 1138908
- rebuild for new libaubio 0.4.5

* Wed May 17 2017 animtim <animtim> 1:5.9.0-1.mga6
+ Revision: 1102282
- update to 5.9.0
  add some configure options

* Mon Mar 06 2017 barjac <barjac> 1:5.8.0-1.mga6
+ Revision: 1088911
- new version 5.8.0

* Wed Dec 21 2016 barjac <barjac> 1:5.5.0-1.mga6
+ Revision: 1076253
- new version 5.5.0

* Wed Oct 19 2016 barjac <barjac> 1:5.4.0-1.mga6
+ Revision: 1062177
- new version 5.4.0
- new BuildRequires: pkgconfig(libarchive)

* Wed Sep 07 2016 barjac <barjac> 1:5.3.0-2.mga6
+ Revision: 1050289
- fix missing desktop icon

* Mon Sep 05 2016 barjac <barjac> 1:5.3.0-1.mga6
+ Revision: 1050041
- new release 5.3.0
- fix files list
- fix Note about Source0 now available without email

* Mon Mar 28 2016 neoclust <neoclust> 1:4.7.0-3.mga6
+ Revision: 996045
- Rebuild now that aubio is available on ARM

* Sun Feb 21 2016 barjac <barjac> 1:4.7.0-2.mga6
+ Revision: 975369
- rebuild for arm

* Sun Feb 21 2016 barjac <barjac> 1:4.7.0-1.mga6
+ Revision: 975280
- new version 4.7.0

* Fri Jan 15 2016 barjac <barjac> 1:4.6.0-2.mga6
+ Revision: 923197
- let users deal with groups
- added README.urpmi to explain how

* Thu Jan 14 2016 barjac <barjac> 1:4.6.0-1.mga6
+ Revision: 922945
- new version 4.6.0

* Thu Dec 17 2015 barjac <barjac> 1:4.4.0-1.mga6
+ Revision: 911525
- import package ardour


* Sun Oct 24 2010 Oden Eriksson <oeriksson@mandriva.com> 1:2.8.11-2mdv2011.0
+ Revision: 587868
- P8: security fix for CVE-2010-3349

* Sun Aug 08 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8.11-1mdv2011.0
+ Revision: 567587
- update to new version 2.8.11
- drop patch 0
- drop ppc and ppc64 bits in spec file

* Sun Feb 21 2010 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8.7-1mdv2010.1
+ Revision: 508885
- update to new version 2.8.7

* Mon Jan 25 2010 Funda Wang <fwang@mandriva.org> 1:2.8.6-1mdv2010.1
+ Revision: 496210
- new version 2.8.6

* Thu Dec 31 2009 Ahmad Samir <ahmadsamir@mandriva.org> 1:2.8.4-1mdv2010.1
+ Revision: 484479
- rediff patches
- add patch to fix wiimote scons file

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - update to new version 2.8.4

* Sat Oct 10 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8.2-3mdv2010.0
+ Revision: 456571
- add missing buildrequires on desktop-file-utils
- rebuild for new curl SSL backend

* Wed Aug 05 2009 Funda Wang <fwang@mandriva.org> 1:2.8.2-2mdv2010.0
+ Revision: 409960
- rebuild
- disable fdo actions

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - add buildrequires on libredland-devel
    - add support for resuming last states
    - link against newer soundtouch library
    - update to new version 2.8.2

* Sun May 17 2009 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.8-1mdv2010.0
+ Revision: 376625
- enable FREEDESKTOP option

  + trem <trem@mandriva.org>
    - update to 2.8
    - fix patch 0 and 4
    - disable FREEDESKTOP because if break the compilation

* Sat Dec 06 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.7.1-1mdv2009.1
+ Revision: 311386
- update to new version 2.7.1

* Sun Nov 23 2008 Oden Eriksson <oeriksson@mandriva.com> 1:2.7-2mdv2009.1
+ Revision: 305982
- really enable wiimote (S1), upstream forgot it...

* Sat Nov 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.7-1mdv2009.1
+ Revision: 305938
- enable wiimote support
- fix file list one more time
- fix file list
- update to new version 2.7
- build against system wide libs only mdv greater than 2009.0 (glibmm issue)

* Thu Nov 06 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.6.1-1mdv2009.1
+ Revision: 300370
- drop patch 2, fixed upstream
- enable runtime FPU optimizations
- compile against stystem-wide libraries(works again)
- update to new version 2.6.1

* Sun Aug 24 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.5-1mdv2009.0
+ Revision: 275505
- Patch4: fix building with gcc43
- compile with SYSLIBS=0, because there are problems with redefined declarations in glibmm and boost
- drop patch 4, fixed differently by upstream
- use aubio library features
- enable sse for x86_64
- add support for aubio library
- add support for fd.o mime-types etc.
- disable patch5, fixed upstream
- update to new version 2.5

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild early 2009.0 package (before pixel changes)

  + Pixel <pixel@mandriva.com>
    - rpm filetriggers deprecates update_menus/update_scrollkeeper/update_mime_database/update_icon_cache/update_desktop_database/post_install_gconf_schemas

  + Oden Eriksson <oeriksson@mandriva.com>
    - bump release
    - added a gcc43 patch from fedora

* Fri Apr 18 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.4.1-1mdv2009.0
+ Revision: 195500
- new version
- fix file list

  + Oden Eriksson <oeriksson@mandriva.com>
    - update url

* Sun Mar 09 2008 Oden Eriksson <oeriksson@mandriva.com> 1:2.3.1-1mdv2008.1
+ Revision: 183023
- fix build deps (lv2core-devel)
- 2.3.1
- added 2 patches from fedora
- fix build deps

  + Tomasz Pawel Gajc <tpg@mandriva.org>
    - new version

* Tue Jan 22 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.2-2mdv2008.1
+ Revision: 156029
- disable cpu optimisations during compling
- use mandriva common optflags rather than hardcoded one

* Mon Jan 21 2008 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.2-1mdv2008.1
+ Revision: 155443
- fix file list
- new version

  + Olivier Blin <oblin@mandriva.com>
    - restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - kill re-definition of %%buildroot on Pixel's request

* Fri Oct 19 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.1-1mdv2008.1
+ Revision: 100128
- new version
- new license policy
- drop patches 0 and 2 (fixed upstream)
- add compile options
- spec file clean

* Fri Aug 31 2007 Funda Wang <fwang@mandriva.org> 1:2.0.5-6mdv2008.0
+ Revision: 77179
- fix menu entry comment

  + Thierry Vignaud <tv@mandriva.org>
    - kill desktop-file-validate's 'warning: key "Encoding" in group "Desktop Entry" is deprecated'

* Wed Aug 22 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.0.5-2mdv2008.0
+ Revision: 68770
- added two patches from the author (all patches will be in 2.0.6)
- don't use %%{optfflags} but build against system libs for now

* Sun Aug 05 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.0.5-1mdv2008.0
+ Revision: 59098
- 2.0.5
- fix deps

* Fri Aug 03 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.0.4-2mdv2008.0
+ Revision: 58532
- rebuild

* Wed Aug 01 2007 Oden Eriksson <oeriksson@mandriva.com> 1:2.0.4-1mdv2008.0
+ Revision: 57631
- 2.0.4
- major rework, build it against system libs

  + Austin Acton <austin@mandriva.org>
    - new version

* Sat May 26 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.0.2-1mdv2008.0
+ Revision: 31316
- new version

* Tue May 15 2007 Austin Acton <austin@mandriva.org> 1:2.0.1-4mdv2008.0
+ Revision: 26975
- fix file list
- fix executable name

* Thu May 10 2007 Austin Acton <austin@mandriva.org> 1:2.0.1-3mdv2008.0
+ Revision: 25844
- buildconflicts libsndfile and libflac

* Wed May 09 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.0.1-1mdv2008.0
+ Revision: 25814
- new version (bugfixes)

* Wed May 09 2007 Austin Acton <austin@mandriva.org> 1:2.0-4mdv2008.0
+ Revision: 25372
- oops, still need old icons too

* Tue May 08 2007 Austin Acton <austin@mandriva.org> 1:2.0-3mdv2008.0
+ Revision: 25299
- use bundled icons, and make them XDG-compliant

* Mon May 07 2007 Tomasz Pawel Gajc <tpg@mandriva.org> 1:2.0-2mdv2008.0
+ Revision: 23950
- own missing files
- drop Sources 3,4,8
- spec file clean
- update description
- update file list
- update to 2.0


* Tue Jan 16 2007 Nicolas Lécureuil <neoclust@mandriva.org> 0.99.3-3mdv2007.0
+ Revision: 109489
- Rebuild against new curl
- Import ardour

* Fri Aug 18 2006 Emmanuel Andry <eandry@mandriva.org> 0.99.3-2mdv2007.0
- xdg menu
- fix description

* Fri May 19 2006 Austin Acton <austin@mandriva.org> 0.99.3-1mdk
- 0.99.3

* Sun Apr 30 2006 Emmanuel Blindauer <blindauer@mandriva.org> 0.99.2-2mdk
- Fix build on ppc

* Sun Feb 26 2006 Austin Acton <austin@mandriva.org> 0.99.2-1mdk
- 0.99.2

* Thu Nov 03 2005 Pascal Terjan <pterjan@mandriva.org> 0.99-1mdk
- 0.99
- Now uses scons instead of make
- Do not build text interface as ardour_ksi/ is not included in 0.99 tarball

* Wed Mar 16 2005 Austin Acton <austin@mandrake.org> 0.9-0.beta28.1mdk
- 0.9beta28
- source URL

* Sat Jan 29 2005 Austin Acton <austin@mandrake.org> 0.9-0.beta24.1mdk
- 0.9beta24

* Thu Dec 30 2004 Austin Acton <austin@mandrake.org> 0.9-0.beta22.1mdk
- 0.9beta22
- configure 2.5

* Sun Dec 12 2004 Austin Acton <austin@mandrake.org> 0.9-0.beta19.1mdk
- 0.9beta19

* Tue Feb 17 2004 Austin Acton <austin@mandrake.org> 0.9-0.beta10.2.1mdk
- 0.9beta10.2

